@@ -25,7 +25,7 @@
 #define UAGENT "VKontakte Agent 1.0"
 #define PAGE_SIZE 20
 #define PREFIX "vk"
-#define MAX_COUNTER 10
+#define MAX_COUNTER 200
 #define MID_SIZE 100
 #define URL_SIZE 1024
 
@@ -62,8 +62,6 @@
 #include <libxslt/xsltInternals.h>
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
-#include "vkontakte.h"
-
 
 #include <string.h>
 #include <glib.h>
@@ -72,6 +70,10 @@
 #include <curl/types.h>
 #include <curl/easy.h>
 #include <glib/gprintf.h>
+
+#include "vkontakte.h"
+#include "profile.h"
+
 #define REQ "request.xml"
 #define AUTH "auth.xml"
 #define UTF8 "utf-8"
@@ -82,27 +84,65 @@
 #define NUMBER "number"
 #define NAME "name"
 
-
-
 struct MemoryStruct {
     char* memory;
     size_t size;
 };
+
+gchar *info_proxy;
+gint info_port;
+
+#define LOGIN "login"
+#define PASSWORD "password"
+
+/**
+ * Allocate memory
+ *
+ * @param ptr - pointer
+ * @param size - size of data
+* @return 0 on success or 1 otherwise.
+ */
+void* myrealloc(void* ptr, size_t size);
+
 extern int init_event_manager(int time);
-int authorize(char *email, char *pass);
-int initialization(char** remixmid, char** remixsid);
-int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info);
+
+/**
+ * Authorization (get remixsid and remixmid for future requests)
+ *
+ * @param cp - current profile
+ * @return 0 on success or 1 otherwise.
+ */
+int authorize(struct ProfileData *cp);
+int initialization(struct ProfileData *cp);
+int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, const struct msa_module* info);
 xmlChar* get_req_class(xmlDocPtr reqXml);
 xmlChar* get_req_function(xmlDocPtr reqXml);
 int captcha_message(xmlDocPtr doc, xmlDocPtr reqXml);
-int http_get(const char* url, const char* proxy, long port, char** header, char** body);
-int http_post(const char* url, const char* proxy, long port, char* post_data, char** header, char** body, struct curl_slist** cookies);
-int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid);
+int http_get(const char* url, const char* proxy, const int port, char** header, gchar** body);
+int http_post(const char* url, const char* proxy, const int port, char* post_data, char** header, char** body, struct curl_slist** cookies);
+
+/**
+ * Perform request
+ *
+ * @param reqXml - request
+ * @param doc - response
+ * @param cp - current profile
+* @return 0 on success or 1 otherwise.
+ */
+int make_request(xmlDocPtr reqXml, xmlDocPtr doc, struct ProfileData *cp);
 int read_message(xmlDocPtr reqXml, char* remixmid, char* remixsid);
 gchar* make_url(xmlDocPtr reqXml, char* remixmid, char* remixsid);
-int get_settings(xmlDocPtr doc);
-int set_settings(xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info);
-void unset_settings(char* name);
+int get_settings(xmlDocPtr doc, const struct ProfileData *cp);
+
+/**
+ * Set settings in to current profile
+ *
+ * @param reqXml - request
+ * @param cp - current profile
+ * @return 0 on success or 1 otherwise.
+ */
+int set_settings(xmlDocPtr reqXml, struct ProfileData *cp);
 int info_message(char* code, xmlDocPtr doc, char* message, int type);
 xmlXPathObject* xpath(char* req, xmlDocPtr doc);
+xmlNodePtr xpath_get_node(char* path, xmlDocPtr doc);
 #endif
